@@ -1,13 +1,10 @@
 import pandas as pd
 import numpy as np
 
-from scipy.stats import t
-from scipy.stats import norm
+from scipy.stats import norm, boxcox
 
 from typing import Union
 
-from tscausalinference.seasonality import yearly_season, weekly_season
-
 import warnings
 warnings.simplefilter(action='ignore', category=FutureWarning)
 
@@ -15,6 +12,59 @@ def min_max_scale(data, min_range, max_range):
     data_min, data_max = data.min(), data.max()
     return (data - data_min) * (max_range - min_range) / (data_max - data_min) + min_range
 
+def structural_bootstrap(data, block_size):
+    num_blocks = int(np.ceil(len(data) / block_size))
+    block_indices = np.random.randint(0, len(data) - block_size + 1, size=num_blocks)
+    resampled_blocks = np.array([data[i:i + block_size] for i in block_indices])
+    resampled_data = resampled_blocks.flatten()[:len(data)]
+    return resampled_data
+
+def random_walk_bootstrap(bootstrap_samples, n_samples, n_steps, variable, mape):
+
+    # Loop over number of bootstrap samples
+    for i in range(n_samples):
+
+      # Resample data with replacement
+      bootstrap_data = np.random.choice(variable, size=len(variable))#, replace=True)
+      
+      # Simulate random walk based on bootstrap data
+      walk = np.cumsum(np.random.randn(n_steps))
+      walk -= walk[0]
+
+      walk *= bootstrap_data.std() / walk.std()
+      walk += bootstrap_data.mean()
+
+      # Smooth the simulated random walk using an exponential moving average filter
+      smoother = 2  # the amount of smoothing on either side
+      alpha = 1 / (smoother + 1)
+      walk_smoothed = pd.Series(walk).ewm(alpha=alpha).mean().values
+
+      bootstrap_samples[i] = walk_smoothed.copy()
+
+    return bootstrap_samples
+
+def prior_bootstrap(bootstrap_samples, n_samples, n_steps, variable, mape):
+    min_range = variable.min() * (1 - mape)
+    max_range = variable.max() * (mape + 1)
+
+    # Loop over number of bootstrap samples
+    for i in range(n_samples):
+
+      # Resample data with replacement
+      bootstrap_data = np.random.choice(variable, size=len(variable))
+      
+      # Simulate random walk based on bootstrap data
+      walk = np.cumsum(np.random.normal(loc=0, scale=bootstrap_data.std(), size=n_steps))
+      walk += bootstrap_data.mean()
+
+      walk = min_max_scale(walk, min_range, max_range)
+      walk = variable.values - (np.mean(variable.values) - np.mean(walk))
+
+      #Save random walk as one of the bootstrap samples
+      bootstrap_samples[i] = walk.copy()
+    
+    return bootstrap_samples
+
 def prob_in_distribution(data, x):
   """
     Calculate the probability of a given value being in a distribution defined by the given data.
@@ -42,13 +92,13 @@ def prob_in_distribution(data, x):
   cdf_upper = 1 - norm.cdf(upper_bound, mean, std)
 
   if x < lower_bound or x > upper_bound:
-      return 0.0
+    return 0.0
   else:
-      cdf_x = norm.cdf(x, mean, std)
-      if cdf_x <= 0.5:
-          return 2 * (cdf_x - cdf_lower) / (1 - cdf_lower - cdf_upper)
-      else:
-          return 2 * (1 - cdf_x + cdf_lower) / (1 - cdf_lower - cdf_upper)
+    cdf_x = norm.cdf(x, mean, std)
+    if cdf_x <= 0.5:
+        return 2 * (cdf_x - cdf_lower) / (1 - cdf_lower - cdf_upper)
+    else:
+        return 2 * (1 - cdf_x + cdf_lower) / (1 - cdf_lower - cdf_upper)
 
 def bootstrap_simulate(
                     variable: Union[np.array, pd.DataFrame] = None, 
@@ -83,40 +133,11 @@ def bootstrap_simulate(
     """
     # Initialize array to hold bootstrap samples
     bootstrap_samples = np.empty((n_samples, n_steps))
-    
-    # Loop over number of bootstrap samples
-    for i in range(n_samples):
-        min_range = variable.min() * (1 - mape)
-        max_range = variable.max() * (mape + 1)
 
-        # Resample data with replacement
-        bootstrap_data = np.random.choice(variable, size=len(variable))#, replace=True)
-        
-        # Simulate random walk based on bootstrap data
-        walk = np.cumsum(np.random.randn(n_steps))
-        walk -= walk[0]
-
-        walk *= bootstrap_data.std() / walk.std()
-        walk += bootstrap_data.mean()
-
-        # Smooth the simulated random walk using a moving average filter
-        smoother = 2  # the amount of smoothing on either side
-        
-        # Pad the beginning and end of the input array
-        pad_size = smoother
-        padded_walk = np.pad(walk, (pad_size, pad_size), mode='edge')
-        
-        # Apply the smoothing filter
-        walk_smoothed = np.convolve(padded_walk, np.ones(2*smoother+1)/(2*smoother+1), mode='valid')
-        walk = walk_smoothed.copy()
-
-        if prio:
-            info = variable.values
-            walk = info + (np.mean(walk) - np.mean(info))
-
-        # Limiting the walk and Save random walk as one of the bootstrap samples
-        walk = min_max_scale(walk, min_range, max_range)
-        bootstrap_samples[i] = walk.copy()
+    if prio:
+      bootstrap_samples = prior_bootstrap(bootstrap_samples, n_samples, n_steps, variable, mape)
+    else:
+      bootstrap_samples = random_walk_bootstrap(bootstrap_samples, n_samples, n_steps, variable, mape)
     
     return bootstrap_samples
     
@@ -169,12 +190,14 @@ def bootstrap_p_value(
     mean_treatment = np.mean(treatment)
         
     bootstrapped_means = np.empty(len(simulations))
+    norm_simulations = simulations.copy()
     
-    for i in range(len(simulations)):
-        bootstrapped_means[i] = simulations[i].mean()
+    for i in range(len(norm_simulations)):
+        norm_simulations[i] -= mean
+        bootstrapped_means[i] = norm_simulations[i].mean()
     
     lower, upper = np.percentile(bootstrapped_means, [alpha / 2 * 100, (1 - alpha / 2) * 100])
     
     p_value = prob_in_distribution(bootstrapped_means, mean_treatment)
 
-    return [p_value], [lower, upper], bootstrapped_means
\ No newline at end of file
+    return [p_value], [lower, upper], bootstrapped_means, norm_simulations
\ No newline at end of file
