@@ -66,7 +66,7 @@ class tscausalinference:
         
         self.string_filter = "ds >= '{}' & ds <= '{}'".format(intervention[0], intervention[1])
         
-    def run(self, prio = False):
+    def run(self, prior = False):
         """
         Runs the causal analysis with the specified configuration.
 
@@ -92,10 +92,10 @@ class tscausalinference:
             n_samples = self.n_samples, 
             n_steps = len(self.data.query(self.string_filter).index),
             mape = abs(round(self.pre_int_metrics[2][1],6)) / 100,
-            prio = prio
+            prio = prior
             )
         
-        self.stadisticts, self.stats_ranges, self.samples_means = bootstrap_p_value(control = self.data.query(self.string_filter).yhat, 
+        self.stadisticts, self.stats_ranges, self.samples_means, self.norm_simulations = bootstrap_p_value(control = self.data.query(self.string_filter).yhat, 
                                                                                     treatment = self.data.query(self.string_filter).y, 
                                                                                     simulations = self.simulations
                                                                                     )
@@ -129,7 +129,7 @@ class tscausalinference:
             plot_intervention(data = self.data, past_window = past_window, back_window = back_window, figsize = figsize, intervention = self.intervention)
         elif method == 'simulations':
             plot_simulations(data = self.data, past_window = past_window, back_window = back_window, figsize = figsize, simulation_number = simulation_number,
-                             intervention = self.intervention, simulations = self.simulations, stadisticts = self.stadisticts, 
+                             intervention = self.intervention, simulations = self.norm_simulations, stadisticts = self.stadisticts, 
                              stats_ranges = self.stats_ranges, samples_means = self.samples_means)
         elif method == 'decomposition':
             seasonal_decompose(data = self.data, intervention = self.intervention, figsize = figsize)
@@ -261,7 +261,7 @@ class sensitivity:
         self.verbose = verbose
         self.n_samples = n_samples
 
-    def run(self, prio = False):
+    def run(self, prior = False):
         """
         Runs the sensitivity analysis with the specified configuration.
 
@@ -283,7 +283,7 @@ class sensitivity:
                          regressors= self.regressors,
                          verbose = self.verbose,
                          n_samples = self.n_samples,
-                         prio = prio,
+                         prio = prior,
                          autocorrelation = self.autocorrelation,
                          model_type = self.model_type)
         return self
