@@ -114,9 +114,7 @@ def synth_analysis(df: DataFrame = None,
         
         print('Default parameters grid: \n{}',format(model_parameters))
     else:
-        model_params.update({'interval_width': 1 - alpha})
         model_parameters = model_params.copy()
-        print('Custom parameters grid: \n{}',format(model_parameters))
     
     pre_intervention = [df.ds.min(),(pd.to_datetime(intervention[0]) - pd.Timedelta(days=1)).strftime('%Y-%m-%d')]
     post_intervention = [(pd.to_datetime(intervention[0]) + pd.Timedelta(days=1)).strftime('%Y-%m-%d'),df.ds.max()]
@@ -132,8 +130,12 @@ def synth_analysis(df: DataFrame = None,
     print('Training period: {} to {}'.format(pre_intervention[0], pre_intervention[1]))
     print('Test period: {} to {}\n'.format(intervention[0], intervention[1]))
     print('Prediction horizon: {} days'.format(prediction_period))
-
-    if len(model_parameters[list(model_parameters.keys())[0]]) > 1:
+    
+    condition_int = isinstance(model_parameters[list(model_parameters.keys())[0]], float)
+    condition_float = isinstance(model_parameters[list(model_parameters.keys())[0]], int)
+    condition_str = isinstance(model_parameters[list(model_parameters.keys())[0]], str)
+    
+    if not (condition_int)|(condition_float)|(condition_str):
         print('Grid Search Cross-Validation mode:\n')
         if isinstance(model_parameters[list(model_parameters.keys())[0]], list):
             # Generate all combinations of parameters
@@ -159,6 +161,8 @@ def synth_analysis(df: DataFrame = None,
             raise TypeError("Your parameters on the Grid are not list type")
     
     else:
+        model_parameters.update({'interval_width': 1 - alpha})
+        print('Custom parameters grid: \n{}',format(model_parameters))
         prophet = Prophet(**model_parameters)
 
     for regressor in regressors:
@@ -194,6 +198,7 @@ def synth_analysis(df: DataFrame = None,
 
     # print response
     print(f'\nCross-validation MAPE: {model_mape_mean:.2%}')
+    print('\nSeasons detected: {}'.format(list(prophet.seasonalities.keys())))
     if len(regressors) >= 1:
         regressor_df = regressor_coefficients(prophet)
         # format table
@@ -203,13 +208,7 @@ def synth_analysis(df: DataFrame = None,
 
         print(tabulate(table, headers=['Regressor', 'Regressor Mode', 'Center', 'Coef. Lower', 'Coef', 'Coef. Upper'], tablefmt='grid'))
 
-    print('\nSeasons detected: {}'.format(list(prophet.seasonalities.keys())))
-    pre_int_metrics = [
-    ['r2', r2_score(y_pred = data[(data.ds >= pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].yhat, y_true = data[(data.ds >= pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].y)],
-    ['MAE', mean_absolute_error(y_pred = data[(data.ds >= pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].yhat, y_true = data[(data.ds >= pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].y)],
-    ['MAPE (%)', mape(y_pred = data[(data.ds >= pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].yhat, y_true = data[(data.ds >= pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].y)],
-    ['Noise (Std)', np.std(data[(data.ds >= pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].y - data[(data.ds >= pd.to_datetime(pre_intervention[0]))&(data.ds <= pd.to_datetime(pre_intervention[1]))&(data.y > 0)].yhat)]
-    ]
+case
 
     strings_info = """
 +------------------------+
